@@ -102,10 +102,12 @@ extract_varcomp.lme <- function(mod, separate_variances = FALSE, vector = FALSE)
   names(Tau_params) <- mapply(gsub, ".sd", ".var", names(Tau_params), USE.NAMES = FALSE)
 
   # split Tau by grouping variables
-  group_names <- lapply(mod$modelStruct$reStruct, function(x) attr(x, "Dimnames")[[1]])
+  reStruct_names <- names(mod$modelStruct$reStruct)
+  group_names <- lapply(rev(mod$modelStruct$reStruct), function(x) attr(x, "Dimnames")[[1]])
+
   group_names <- lapply(group_names, function(x) gsub("([\\(\\)\\^\\.])","\\\\\\1", x))
   group_regx <- paste0("^",names(group_names), ".+\\((",lapply(group_names, paste, collapse = "|"), ")")
-  names(group_regx) <- names(group_names)
+  names(group_regx) <- make.unique(names(group_names))
 
   Tau_param_list <- sapply(group_regx,
                            function(x) Tau_params[grepl(x, names(Tau_params))],
